@@ -1,5 +1,7 @@
+# -*- coding: utf-8 -*-
 #
 #   Copyright [2011] [Patrick Ancillotti]
+#   Copyright [2011] [Jason Kölker]
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -14,4 +16,4 @@
 #   limitations under the License.
 #
 
-__version__ = '1.0.6'
+from main import main
